@@ -53,7 +53,7 @@ typedef struct _vumeter {
 static short aubuf[BUFS][NSAMP];
 static GtkWidget *dial[2];
 static GtkWidget *window;
-static char *esd_host = NULL;
+static gchar *esd_host = NULL;
 static int curbuf = 0;
 static int lag = 2;
 static int plevel_l = 0;
@@ -176,7 +176,7 @@ handle_read (gpointer data,
 	static int to_get = NSAMP*2;
 	static int count;
 
-	count = read(source, aubuf[curbuf] + pos, to_get);
+	count = read(source, ((char *) aubuf[curbuf]) + pos, to_get);
 	if (count <0) {
 		exit(1);		/* no data */
 	} else {
@@ -212,6 +212,8 @@ main (int argc,
       char *argv[])
 {
 	GnomeClient *client;
+	GdkGeometry hints;
+	GOptionContext *goption_context;
 	GtkWidget *hbox;
 	GtkWidget *frame;
 	vumeter *meter;
@@ -219,38 +221,37 @@ main (int argc,
 	int i;
 	gint          session_xpos = -1;
 	gint          session_ypos = -1;
-	gint          orient = 0;
-	gint          record = 0;
+	gboolean      orient = FALSE;
+	gboolean      record = FALSE;
 
-	struct poptOption options[] = 
+	GOptionEntry options[] = 
 	{
-		{ NULL, 'x', POPT_ARG_INT, NULL, 0, 
+		{ "xpos", 'x', 0, G_OPTION_ARG_INT, &session_xpos, 
 		  N_("Specify the X position of the meter."), 
-		  N_("X-Position") },
-		{ NULL, 'y', POPT_ARG_INT, NULL, 0, 
+		  N_("X") },
+		{ "ypos", 'y', 0, G_OPTION_ARG_INT, &session_ypos, 
 		  N_("Specify the Y position of the meter."), 
-		  N_("Y-Position") },
-		{ NULL, 's', POPT_ARG_STRING, NULL, 0, 
+		  N_("Y") },
+		{ "server", 's', 0, G_OPTION_ARG_STRING, &esd_host, 
 		  N_("Connect to the esd server on this host."), 
-		  N_("ESD Server Host") },
-		{ NULL, 'v', POPT_ARG_NONE, NULL, 0, 
+		  N_("HOST") },
+		{ "vertical", 'v', 0, G_OPTION_ARG_NONE, &orient, 
 		  N_("Open a vertical version of the meter."), NULL },
-		{ NULL, 'r', POPT_ARG_NONE, NULL, 0, 
+		{ "record", 'r', 0, G_OPTION_ARG_NONE, &record, 
 		  N_("Act as recording level meter."), NULL },
-		{ NULL, '\0', 0, NULL, 0 }
+		{ NULL }
 	};
 
-	options[0].arg = &session_xpos;
-	options[1].arg = &session_ypos;
-	options[2].arg = &esd_host;
-	options[3].arg = &orient;
-	options[4].arg = &record;
-	
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
-	gnome_init_with_popt_table ("vumeter", VERSION, argc, argv, options, 
-				    0, NULL);
+
+	goption_context = g_option_context_new(NULL);
+	g_option_context_add_main_entries(goption_context, options, GETTEXT_PACKAGE);
+
+	gnome_program_init ("vumeter", VERSION, LIBGNOMEUI_MODULE, argc, argv,
+				    GNOME_PARAM_GOPTION_CONTEXT, goption_context, 
+				    NULL);
 #ifdef DEBUG
 	if (esd_host) {
 		g_print (_("Host is %s\n"), esd_host);
@@ -267,8 +268,8 @@ main (int argc,
 			  G_CALLBACK (gtk_main_quit), argv[0]);
 	
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (window),
-					 GNOME_ICONDIR"/gnome-vumeter.png");
+	gtk_window_set_icon_name (GTK_WINDOW (window),
+	                          (record ? "gnome-reclevel" : "gnome-vumeter"));
 	gtk_window_set_title (GTK_WINDOW (window),
 			      (record ? _("Recording level") : _("Volume Meter") ));
 	if (session_xpos >=0 && session_ypos >= 0) {
@@ -295,10 +296,32 @@ main (int argc,
 	gtk_container_add (GTK_CONTAINER (frame), hbox);
 	
 	for (i = 0; i < 2; i++) {
-		dial[i] = led_bar_new (25, orient);
-		gtk_box_pack_start (GTK_BOX (hbox), dial[i], FALSE, FALSE, 0);
+		/* 20 segments is the max in gtkledbar.c */
+		dial[i] = led_bar_new (20, orient);
+		gtk_box_pack_start (GTK_BOX (hbox), dial[i], TRUE, TRUE, 0);
 	}
 	
+	/* set to -1 to use the requisition */
+	hints.base_width = -1;
+	hints.base_height = -1;
+	hints.min_width = -1;
+	hints.min_height = -1;
+
+	/* since each led starts at a width of 10, (see gtkled.c) then
+	 * to increase each led by 1px, we set the incremenet width to
+	 * num_segments * 1px = 20px */
+	hints.width_inc = 20;
+	
+	/* arbitrary */
+	hints.height_inc = 20;
+
+	gtk_window_set_geometry_hints (GTK_WINDOW (window),
+				       NULL,
+				       &hints,
+				       GDK_HINT_RESIZE_INC |
+				       GDK_HINT_MIN_SIZE |
+				       GDK_HINT_BASE_SIZE);
+	
 	gtk_widget_show_all (window);
 	open_sound(record);
 	fcntl(sound, F_SETFL, O_NONBLOCK);
